@@ -1,5 +1,3 @@
-//$Id: deriveddialog.cc 588 2004-02-13 17:10:43Z murrayc $ -*- c++ -*-
-
 /* libglademm example Copyright (C) 2003 libglademm development team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -31,11 +29,26 @@ DerivedDialog::DerivedDialog(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Bu
   }
 }
 
+// The first two parameters are mandatory in a constructor that will be called
+// from Gtk::Builder::get_widget_derived().
+// Additional parameters, if any, correspond to additional arguments in the call
+// to Gtk::Builder::get_widget_derived().
+DerivedDialog::DerivedDialog(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& refGlade,
+  bool is_glad)
+: DerivedDialog(cobject, refGlade) // Delegate to the other constructor
+{
+  // Show an icon.
+  auto pImage = Gtk::manage(new Gtk::Image());
+  pImage->set_from_icon_name(is_glad ? "face-smile" : "face-sad", Gtk::ICON_SIZE_DIALOG);
+  pImage->show_all();
+  get_content_area()->pack_start(*pImage);
+}
+
 DerivedDialog::~DerivedDialog()
 {
 }
 
 void DerivedDialog::on_button_quit()
 {
-  hide(); //hide() will cause main::run() to end.
+  hide(); //hide() will cause Gtk::Application::run() to end.
 }
